@@ -6,6 +6,7 @@ from robot.libraries.BuiltIn import BuiltIn
 from robot.libraries.Collections import Collections
 from robot.libraries.OperatingSystem import OperatingSystem
 from robot.api.deco import keyword
+from robot.utils import DotDict
 
 
 class ApiLibKeywords(object):
@@ -315,8 +316,7 @@ class ApiLibKeywords(object):
         try:
             content_to_json = response.json()
             if not isinstance(content_to_json, list):
-                self.builtin.set_test_variable("${current_response_content}", content_to_json)
-                response_dict['json'] = self.builtin.create_dictionary("&{current_response_content}")
+                response_dict['json'] = DotDict(content_to_json.items())
             else:
                 response_dict['json'] = content_to_json
             response_dict['is_valid_json'] = True
@@ -325,12 +325,10 @@ class ApiLibKeywords(object):
             response_dict['is_valid_json'] = False
 
         try:
-            self.builtin.set_test_variable("${current_response_headers}", response.headers)
-            response_dict['headers'] = self.builtin.create_dictionary("&{current_response_headers}")
+            response_dict['headers'] = DotDict(response.headers.items())
         except:
             response_dict['headers'] = response.headers
-        self.builtin.set_test_variable("${current_response}", response_dict)
-        return response, self.builtin.create_dictionary("&{current_response}")
+        return response, DotDict(response_dict.items())
 
     def _to_json(self, content):
         PY3 = sys.version_info > (3,)
@@ -443,9 +441,7 @@ class ApiLibKeywords(object):
         """
         json_file = self.operatingsystem.get_file(file_path)
         json_file = self._to_json(json_file)
-        self.builtin.set_test_variable("${json_file_python}", json_file)
-        json_file = self.builtin.create_dictionary("&{json_file_python}")
-        return json_file
+        return DotDict(json_file.items())
     
     @keyword
     def check_response_length_limit(self, content, limit):
